#[non_exhaustive]pub enum Ed25519KeyPairParseError {
InvalidOid {
expected: ObjectIdentifier,
found: ObjectIdentifier,
},
InvalidSecretKeyLength {
expected: usize,
found: usize,
},
PublicKeyMismatch {
derived: Vec<u8>,
parsed: Vec<u8>,
},
Pkcs8(Error),
}Available on crate feature
signatures only.Expand description
An error encountered when constructing an Ed25519KeyPair from its constituent parts.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidOid
The ASN.1 Object Identifier on a PKCS#8 document doesn’t match the expected one.
This can happen when the document describes a RSA key, while an ed25519 key was expected.
Fields

expected: ObjectIdentifierThe expected OID.

found: ObjectIdentifierThe OID that was found instead.
InvalidSecretKeyLength
The length of the ed25519 secret key is invalid.
Fields
PublicKeyMismatch
The public key found in a PKCS#8 v2 document doesn’t match the public key derived from its private key.
Fields
Pkcs8(Error)
An error occurred when parsing a PKCS#8 document.