#[non_exhaustive]pub enum VerificationError {
Json(JsonError),
InvalidBase64Signature {
path: String,
source: Base64DecodeError,
},
ParseIdentifier {
identifier_type: &'static str,
source: Error,
},
UnsupportedAlgorithm,
NoSignaturesForEntity(String),
NoPublicKeysForEntity(String),
NoSupportedSignatureForEntity(String),
Ed25519(Ed25519VerificationError),
}Available on crate feature
signatures only.Expand description
Errors relating to verification of signatures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Json(JsonError)
The JSON to check is invalid.
InvalidBase64Signature
Parsing a base64-encoded signature failed.
ParseIdentifier
Parsing a Matrix identifier failed.
Fields
UnsupportedAlgorithm
The signature uses an unsupported algorithm.
NoSignaturesForEntity(String)
The signatures for an entity cannot be found in the signatures map.
NoPublicKeysForEntity(String)
The public keys for an entity cannot be found in the public keys map.
NoSupportedSignatureForEntity(String)
No signature with a supported algorithm was found for the given entity.
Ed25519(Ed25519VerificationError)
Error verifying an ed25519 signature.